%
% [xhat,Phat]=update(xhatp,Phatp,z,H,R)
%
% Computes the kalman filter update for an observation z.
%
% Inputs:
%    xhatp            predicted state.
%    Phatp            covariance of xhatp.
%    z                observation vector.
%    H                matrix relating x and z (z=H*x+v)
%    R                covariance of noise in z.  
%
% Outputs:
%    xhat             updated estimate of the state.
%    Phat             covariance of xhat.
%
function [xhat,Phat]=update(xhatp,Phatp,z,H,R)
%
% Get the size of the xhatp vector.
%
n=length(xhatp);
%
% First, compute K.
%
K=Phatp*H'*inv(H*Phatp*H'+R);
%
% A useful factor.
%
F=eye(n)-K*H;
%
% Next compute the update to xhat.
%
xhat=F*xhatp+K*z;
%
% Compute the update to Phat.
%
Phat=F*Phatp*F'+K*R*K';
